@@ -82,6 +82,8 @@ import           Diagrams.Located
 import           Diagrams.Parametric
 import           Diagrams.Solve.Polynomial
 
+import           Data.Serialize            (Serialize)
+import qualified Data.Serialize            as Serialize
 
 ------------------------------------------------------------
 --  Open/closed type tags  ---------------------------------
@@ -323,6 +325,11 @@ reverseSegment :: (Num n, Additive v) => Segment Closed v n -> Segment Closed v
 reverseSegment (Linear (OffsetClosed v))       = straight (negated v)
 reverseSegment (Cubic c1 c2 (OffsetClosed x2)) = bezier3 (c2 ^-^ x2) (c1 ^-^ x2) (negated x2)
 
+-- Imitates I.elem for intervals<0.8 and I.member for intervals>=0.8
+member :: Ord a => a -> I.Interval a -> Bool
+member x (I.I a b) = x >= a && x <= b
+{-# INLINE member #-}
+
 instance (Metric v, OrderedField n)
       => HasArcLength (Segment Closed v n) where
 
@@ -337,9 +344,9 @@ instance (Metric v, OrderedField n)
   arcLengthToParam m s _ | arcLength m s == 0 = 0.5
   arcLengthToParam m s@(Linear {}) len = len / arcLength m s
   arcLengthToParam m s@(Cubic {})  len
-    | len `I.elem` I (-m/2) (m/2) = 0
+    | len `member` I (-m/2) (m/2) = 0
     | len < 0              = - arcLengthToParam m (fst (splitAtParam s (-1))) (-len)
-    | len `I.elem` slen    = 1
+    | len `member` slen    = 1
     | len > I.sup slen     = 2 * arcLengthToParam m (fst (splitAtParam s 2)) len
     | len < I.sup llen     = (*0.5) $ arcLengthToParam m l len
     | otherwise            = (+0.5) . (*0.5)
@@ -580,3 +587,48 @@ instance (OrderedField n, Metric v)
 
             *: ()
 
+------------------------------------------------------------
+--  Serialize instances
+------------------------------------------------------------
+
+instance (Serialize (v n)) => Serialize (Segment Open v n) where
+  {-# INLINE put #-}
+  put segment = case segment of
+    Linear OffsetOpen    -> Serialize.put True
+    Cubic v w OffsetOpen -> do
+      Serialize.put False
+      Serialize.put v
+      Serialize.put w
+
+  {-# INLINE get #-}
+  get = do
+    isLinear <- Serialize.get
+    case isLinear of
+      True  -> return (Linear OffsetOpen)
+      False -> do
+        v <- Serialize.get
+        w <- Serialize.get
+        return (Cubic v w OffsetOpen)
+
+instance (Serialize (v n)) => Serialize (Segment Closed v n) where
+  {-# INLINE put #-}
+  put segment = case segment of
+    Linear (OffsetClosed z)    -> do
+      Serialize.put z
+      Serialize.put True
+    Cubic v w (OffsetClosed z) -> do
+      Serialize.put z
+      Serialize.put False
+      Serialize.put v
+      Serialize.put w
+
+  {-# INLINE get #-}
+  get = do
+    z <- Serialize.get
+    isLinear <- Serialize.get
+    case isLinear of
+      True  -> return (Linear (OffsetClosed z))
+      False -> do
+        v <- Serialize.get
+        w <- Serialize.get
+        return (Cubic v w (OffsetClosed z))
