@@ -56,6 +56,7 @@ module Diagrams.Trail
 
        , Trail(..)
        , _Line, _Loop
+       , _LocLine, _LocLoop
        , wrapTrail, wrapLine, wrapLoop
        , onTrail, onLine
 
@@ -81,7 +82,7 @@ module Diagrams.Trail
        , trailPoints, linePoints, loopPoints
        , trailVertices', lineVertices', loopVertices'
        , trailVertices, lineVertices, loopVertices
-       , trailLocSegments, fixTrail
+       , trailLocSegments, fixTrail, unfixTrail
 
          -- * Modifying trails
 
@@ -102,7 +103,7 @@ module Diagrams.Trail
 
          -- ** Extracting segments
 
-       , GetSegment(..), getSegment
+       , GetSegment(..), getSegment, GetSegmentCodomain(..)
 
        ) where
 
@@ -127,6 +128,9 @@ import           Linear.Affine
 import           Linear.Metric
 import           Linear.Vector
 
+import           Data.Serialize            (Serialize)
+import qualified Data.Serialize            as Serialize
+
 -- $internals
 --
 -- Most users of diagrams should not need to use anything in this
@@ -554,9 +558,10 @@ instance (Metric v, OrderedField n, Metric u, OrderedField n')
 --   trail, respectively.
 --
 --   The codomain for 'GetSegment', /i.e./ the result you get from
---   calling 'atParam', 'atStart', or 'atEnd', is @Maybe (v, Segment
---   Closed v, AnIso' n n)@.  @Nothing@ results if
---   the trail is empty; otherwise, you get:
+--   calling 'atParam', 'atStart', or 'atEnd', is
+--   'GetSegmentCodomain', which is a newtype wrapper around @Maybe
+--   (v, Segment Closed v, AnIso' n n)@.  @Nothing@ results if the
+--   trail is empty; otherwise, you get:
 --
 --   * the offset from the start of the trail to the beginning of the
 --     segment,
@@ -766,6 +771,14 @@ _Line = _Wrapped' . _Left
 _Loop :: Prism' (Trail v n) (Trail' Loop v n)
 _Loop = _Wrapped' . _Right
 
+-- | Prism onto a 'Located' 'Line'.
+_LocLine :: Prism' (Located (Trail v n)) (Located (Trail' Line v n))
+_LocLine = prism' (mapLoc Trail) $ located (preview _Line)
+
+-- | Prism onto a 'Located' 'Loop'.
+_LocLoop :: Prism' (Located (Trail v n)) (Located (Trail' Loop v n))
+_LocLoop = prism' (mapLoc Trail) $ located (preview _Loop)
+
 instance Rewrapped (Trail v n) (Trail v' n')
 instance Wrapped (Trail v n) where
   type Unwrapped (Trail v n) = Either (Trail' Line v n) (Trail' Loop v n)
@@ -1237,10 +1250,30 @@ select :: [a] -> [Bool] -> [a]
 select xs bs = map fst $ filter snd (zip xs bs)
 
 -- | Convert a concretely located trail into a list of fixed segments.
+--   'unfixTrail' is almost its left inverse.
 fixTrail :: (Metric v, OrderedField n)
          => Located (Trail v n) -> [FixedSegment v n]
 fixTrail t = map mkFixedSeg (trailLocSegments t)
 
+-- | Convert a list of fixed segments into a located trail.  Note that
+--   this may lose information: it throws away the locations of all
+--   but the first @FixedSegment@.  This does not matter precisely
+--   when each @FixedSegment@ begins where the previous one ends.
+--
+--   This is almost left inverse to 'fixTrail', that is, @unfixTrail
+--   . fixTrail == id@, except for the fact that @unfixTrail@ will
+--   never yield a @Loop@.  In the case of a loop, we instead have
+--   @glueTrail . unfixTrail . fixTrail == id@.  On the other hand, it
+--   is not the case that @fixTrail . unfixTrail == id@ since
+--   @unfixTrail@ may lose information.
+unfixTrail
+  :: (Metric v, Ord n, Floating n)
+  => [FixedSegment v n] -> Located (Trail v n)
+unfixTrail = mapLoc trailFromSegments . takeLoc . map fromFixedSeg
+  where
+    takeLoc []       = [] `at` origin
+    takeLoc xs@(x:_) = map unLoc xs `at` loc x
+
 -- | Convert a concretely located trail into a list of located segments.
 trailLocSegments :: (Metric v, OrderedField n)
                   => Located (Trail v n) -> [Located (Segment Closed v n)]
@@ -1311,3 +1344,38 @@ instance (Metric v, OrderedField n) => Reversing (Located (Trail' l v n)) where
 instance (Metric v, OrderedField n) => Reversing (Located (Trail v n)) where
   reversing = reverseLocTrail
 
+------------------------------------------------------------
+--  Serialize instances
+------------------------------------------------------------
+
+instance (Serialize (v n), OrderedField n, Metric v) => Serialize (Trail v n) where
+  {-# INLINE get #-}
+  get = do
+    isLine <- Serialize.get
+    case isLine of
+      True  -> do
+        segTree <- Serialize.get
+        return (Trail (Line segTree))
+      False -> do
+        segTree <- Serialize.get
+        segment <- Serialize.get
+        return (Trail (Loop segTree segment))
+
+  {-# INLINE put #-}
+  put (Trail (Line segTree)) = do
+    Serialize.put True
+    Serialize.put segTree
+
+  put (Trail (Loop segTree segment)) = do
+    Serialize.put False
+    Serialize.put segTree
+    Serialize.put segment
+
+instance (OrderedField n, Metric v, Serialize (v n)) => Serialize (SegTree v n) where
+  {-# INLINE put #-}
+  put (SegTree fingerTree) = Serialize.put (F.toList fingerTree)
+
+  {-# INLINE get #-}
+  get = do
+    fingerTree <- Serialize.get
+    return (SegTree (FT.fromList fingerTree))
