@@ -134,7 +134,7 @@ import           Diagrams.Trail
 import           Diagrams.TwoD.Arrowheads
 import           Diagrams.TwoD.Attributes
 import           Diagrams.TwoD.Path        (stroke, strokeT)
-import           Diagrams.TwoD.Transform   (reflectY, rotate, translateX)
+import           Diagrams.TwoD.Transform   (reflectY, translateX)
 import           Diagrams.TwoD.Types
 import           Diagrams.TwoD.Vector      (unitX, unit_X)
 import           Diagrams.Util             (( # ))
@@ -321,9 +321,10 @@ mkHT xDir htProj styProj sz opts gToO nToO reflect
     ht = stroke ht' # applyStyle (styProj opts)
     j  = stroke j'  # applyStyle (colorJoint (opts^.shaftStyle))
 
--- | Make a trail with the same angles and offset as an arrow with tail width
---   tw, head width hw and shaft of tr, such that the magnituted of the shaft
---   offset is size. Used for calculating the offset of an arrow.
+-- | @spine tr tw hw sz@ makes a trail with the same angles and offset
+--   as an arrow with tail width @t@w, head width @hw@ and shaft @tr@,
+--   such that the magnitude of the shaft offset is @sz@. Used for
+--   calculating the offset of an arrow.
 spine :: TypeableFloat n => Trail V2 n -> n -> n -> n -> Trail V2 n
 spine tr tw hw sz = tS <> tr # scale sz <> hS
   where
@@ -332,8 +333,9 @@ spine tr tw hw sz = tS <> tr # scale sz <> hS
     hS = if hw > 0 then hSpine else mempty
     tS = if tw > 0 then tSpine else mempty
 
---  | Calculate the amount required to scale a shaft trail so that an arrow with
---    head width hw and tail width tw has offset t.
+-- | @scaleFactor tr tw hw t@ calculates the amount required to scale
+--   a shaft trail @tr@ so that an arrow with head width @hw@ and tail
+--   width @tw@ has offset @t@.
 scaleFactor :: TypeableFloat n => Trail V2 n -> n -> n -> n -> n
 scaleFactor tr tw hw t
 
@@ -423,7 +425,7 @@ arrow' opts len = mkQD' (DelayedLeaf delayedArrow)
         opts' = opts
           & headStyle  %~ maybe id fillTexture globalLC
           & tailStyle  %~ maybe id fillTexture globalLC
-          & shaftStyle %~ applyStyle sty
+          & shaftStyle %~ applyStyle sty . transform tr
 
         -- The head size, tail size, head gap, and tail gap are obtained
         -- from the style and converted to output units.
